@@ -1,7 +1,8 @@
 import os
 import re
 import json
-import logging
+
+# import logging
 import requests
 import urllib.request
 from cloudpathlib import S3Client
@@ -22,7 +23,8 @@ from polly.errors import (
 
 import urllib
 import pandas as pd
-import polly.http_response_codes as http_codes
+
+# import polly.http_response_codes as http_codes
 from polly.tracking import Track
 import polly.constants as const
 import string
@@ -194,7 +196,7 @@ def upload_to_S3(cloud_path: str, local_path: str, credentials: dict) -> None:
                 and path_split[len(path_split) - 1][0] in punctuation_chars
             ):
                 raise InvalidParameterException(
-                    f"path can't start with {path_split[len(path_split)-1][0]}"
+                    f"path can't start with {path_split[len(path_split) - 1][0]}"
                 )
             new_source_path = client.CloudPath(cloud_path)
             if new_source_path.exists():
@@ -243,7 +245,7 @@ def download_from_S3(
             # If copy_workspace_path is True, append workspace_path to destination_path to copy the directory structure.
             # ex- make_path('/home/user/project/', 'folder1/folder2') = '/home/user/project/folder1/folder2'
             if copy_workspace_path is True:
-                destination_path = f"{make_path(destination_path,workspace_path)}"
+                destination_path = f"{make_path(destination_path, workspace_path)}"
 
             source_path.copytree(destination_path, force_overwrite_to_cloud=True)
         except ClientError as e:
@@ -667,35 +669,6 @@ def replace_original_name_field(
     return replaced_metadata
 
 
-def upload_html_file(
-    session, workspace_id: int, workspace_path: str, local_report_path: str
-):
-    """
-    Function to upload an html file to a workspace.
-    """
-    upload_url = f"https://v2.api.{session.env}.elucidata.io/workspaces/{workspace_id}/upload_url"
-    params = {"file_path": workspace_path, "content_type": "text/html"}
-    # get request to get the signed url for s3
-    response = session.get(upload_url, params=params)
-    error_handler(response)
-    attributes = response.json().get("data").get("attributes")
-    try:
-        with open(local_report_path, "rb") as file_to_upload:
-            # uploading the local file to the signed url
-            files = {"file": (local_report_path, file_to_upload)}
-            upload_response = requests.post(
-                attributes["url"], data=attributes["fields"], files=files
-            )
-            error_handler(upload_response)
-            if upload_response.status_code == http_codes.CREATED:
-                logging.basicConfig(level=logging.INFO)
-                logging.info(
-                    f"File uploaded successfully to workspace-id = {workspace_id} at path = {workspace_path}!"
-                )
-    except Exception as e:
-        raise e
-
-
 def get_folder_list_from_list_of_filepaths(filenames_fullpath_list: list) -> list:
     """
     gives back only the folders from a list of filepaths provided.
