@@ -548,3 +548,92 @@ class PollyKG:
             return handle_success_and_error_response(response)
         except Exception as e:
             print(e)
+
+    @Track.track_decorator
+    def get_all_kgs(
+        self,
+        include_unpublished: bool = False,
+        include_instances: bool = False,
+        include_terminated: bool = False,
+    ) -> list:
+        """Retrieve all available Knowledge Graphs.
+
+        This function fetches a list of all available Knowledge Graphs (KGs)
+        that the user has access to, including their metadata such as kg_id,
+        kg_name, kg_description, version_id, created_at timestamp, and
+        published status.
+
+        Args:
+            include_unpublished (bool, optional): Include unpublished knowledge graphs.
+                Defaults to False.
+            include_instances (bool, optional): Include instance information for each KG.
+                When True, each KG will include an 'instances' array with details about
+                available instances (instance_id, instance_type, CPU/RAM, etc.).
+                Defaults to False.
+            include_terminated (bool, optional): Include terminated instances in the response.
+                Only applies when include_instances is True. Defaults to False.
+
+        Returns:
+            list: A list of dictionaries, where each dictionary contains:
+                - kg_id (str): Unique identifier for the knowledge graph
+                - kg_name (str): Name of the knowledge graph
+                - kg_description (str): Description of the knowledge graph
+                - version_id (int): Current version ID
+                - created_at (int): Creation timestamp (Unix epoch in milliseconds)
+                - published (bool): Whether the KG is published
+                - instances (list, optional): Available when include_instances=True.
+                  Each instance contains:
+                    - instance_id (str): Unique identifier for the instance
+                    - instance_type (str): Type/size of instance (e.g., "t3.medium")
+                    - is_terminated (bool): Whether the instance is terminated
+                    - default_instance (bool): Whether this is the default instance
+                    - org_id (int): Organization ID
+                    - created_at (int): Instance creation timestamp
+
+        Raises:
+            ResourceNotFoundError: Raised when no knowledge graphs are found.
+            AccessDeniedError: Raised when the user does not have permission to access the KGs.
+            RequestFailureException: Raised when the request fails due to an unexpected error.
+
+        Example:
+            >>> kg = PollyKG()
+            >>> # Get only published KGs
+            >>> kgs = kg.get_all_kgs()
+            >>> for kg_info in kgs:
+            ...     print(f"{kg_info['kg_name']} (ID: {kg_info['kg_id']})")
+            base kg v3 (ID: 14_base_kg_v3)
+
+            >>> # Get all KGs including unpublished ones with instance details
+            >>> kgs_with_instances = kg.get_all_kgs(
+            ...     include_unpublished=True,
+            ...     include_instances=True,
+            ...     include_terminated=True
+            ... )
+            >>> for kg_info in kgs_with_instances:
+            ...     print(f"{kg_info['kg_name']} - {len(kg_info.get('instances', []))} instances")
+        """
+        try:
+            kg_url = f"{self.polly_kg_neo4j_endpoint}/kg"
+
+            # Build query parameters
+            params = {}
+            if include_unpublished:
+                params["include_unpublished"] = "true"
+            if include_instances:
+                params["include_instances"] = "true"
+            if include_terminated:
+                params["include_terminated"] = "true"
+
+            response = self.session.get(kg_url, params=params)
+            handle_success_and_error_response(response)
+
+            data = response.json().get("data", [])
+
+            if not data:
+                raise ResourceNotFoundError(detail="No knowledge graphs found.")
+
+            return data
+
+        except Exception as e:
+            print(e)
+            raise
