@@ -379,6 +379,13 @@ initialize a object that can use all function and methods of Workspaces class.
             )
         if workspace_path.startswith("polly://"):
             workspace_path = workspace_path.split("polly://")[1]
+
+        # If local_path is a file, append its name to workspace_path
+        if os.path.isfile(local_path):
+            file_name = os.path.basename(local_path)
+            if not workspace_path.endswith(file_name):
+                workspace_path = os.path.join(workspace_path, file_name)
+
         s3_path, credentials = self._s3_util(workspace_id, workspace_path)
         helpers.upload_to_S3(s3_path, local_path, credentials)
         logging.basicConfig(level=logging.INFO)
