@@ -120,9 +120,9 @@ class S3ClientManager:
     def _init_client(self) -> S3SessionDetails:
         if (self.omixatlas_id, self.copy_dest_omixatlas_id) not in self._cache:
             session_details = self._get_autorefresh_session()
-            self._cache[
-                (self.omixatlas_id, self.copy_dest_omixatlas_id)
-            ] = session_details
+            self._cache[(self.omixatlas_id, self.copy_dest_omixatlas_id)] = (
+                session_details
+            )
 
         return self._cache[(self.omixatlas_id, self.copy_dest_omixatlas_id)]
 
